# unpacking

`unpacking.packed` is a higher-order function (possibly as a Python decorator) producing an edition of the original function which first internally unpacks (or destructures) its parameter.
